// SPDX-License-Identifier: GPL-2.1-or-later
/*
 * gp_write_pixels.gen.h
 *
 * GENERATED on 2025 03 08 19:32:35 from gp_write_pixels.gen.h.t
 *
 * DO NOT MODIFY THIS FILE DIRECTLY!
 */
#ifndef GP_WRITE_PIXELS_GEN_H
#define GP_WRITE_PIXELS_GEN_H

/*
 * Copyright (C) 2009-2024 Cyril Hrubis <metan@ucw.cz>
 */
/**
 * @file gp_write_pixels.gen.h
 * @brief Optimized functions to write a row of pixels.
 *
 * These functions writes cnt pixels using value val starting at start address
 * and additionally (for pixel sizes that are not aligned to the whole bytes)
 * at off offset in the first byte (i.e. byte at the start address).
 */
#include <stddef.h>
#include <stdint.h>

/**
 * @brief Optimized function to draw a row of 1BPP_DB pixels.
 *
 * @param start A pointer to starting byte in the buffer
 * @param off Number of pixels to skip in the first byte
 * @param cnt A number of pixels to write
 * @param val A pixel value to be written.
 */
void gp_write_pixels_1BPP_DB(void *start, uint8_t off,
                             size_t cnt, unsigned int val);

/**
 * @brief Optimized function to draw a row of 1BPP_UB pixels.
 *
 * @param start A pointer to starting byte in the buffer
 * @param off Number of pixels to skip in the first byte
 * @param cnt A number of pixels to write
 * @param val A pixel value to be written.
 */
void gp_write_pixels_1BPP_UB(void *start, uint8_t off,
                             size_t cnt, unsigned int val);

/**
 * @brief Optimized function to draw a row of 2BPP_DB pixels.
 *
 * @param start A pointer to starting byte in the buffer
 * @param off Number of pixels to skip in the first byte
 * @param cnt A number of pixels to write
 * @param val A pixel value to be written.
 */
void gp_write_pixels_2BPP_DB(void *start, uint8_t off,
                             size_t cnt, unsigned int val);

/**
 * @brief Optimized function to draw a row of 2BPP_UB pixels.
 *
 * @param start A pointer to starting byte in the buffer
 * @param off Number of pixels to skip in the first byte
 * @param cnt A number of pixels to write
 * @param val A pixel value to be written.
 */
void gp_write_pixels_2BPP_UB(void *start, uint8_t off,
                             size_t cnt, unsigned int val);

/**
 * @brief Optimized function to draw a row of 4BPP_DB pixels.
 *
 * @param start A pointer to starting byte in the buffer
 * @param off Number of pixels to skip in the first byte
 * @param cnt A number of pixels to write
 * @param val A pixel value to be written.
 */
void gp_write_pixels_4BPP_DB(void *start, uint8_t off,
                             size_t cnt, unsigned int val);

/**
 * @brief Optimized function to draw a row of 4BPP_UB pixels.
 *
 * @param start A pointer to starting byte in the buffer
 * @param off Number of pixels to skip in the first byte
 * @param cnt A number of pixels to write
 * @param val A pixel value to be written.
 */
void gp_write_pixels_4BPP_UB(void *start, uint8_t off,
                             size_t cnt, unsigned int val);

/**
 * @brief Optimized function to draw a row of 8BPP pixels.
 *
 * @param start A pointer to starting byte in the buffer
 * @param cnt A number of pixels to write
 * @param val A pixel value to be written.
 */
void gp_write_pixels_8BPP(void *start, size_t cnt, unsigned int val);

/**
 * @brief Optimized function to draw a row of 16BPP pixels.
 *
 * @param start A pointer to starting byte in the buffer
 * @param cnt A number of pixels to write
 * @param val A pixel value to be written.
 */
void gp_write_pixels_16BPP(void *start, size_t cnt, unsigned int val);

/**
 * @brief Optimized function to draw a row of 24BPP pixels.
 *
 * @param start A pointer to starting byte in the buffer
 * @param cnt A number of pixels to write
 * @param val A pixel value to be written.
 */
void gp_write_pixels_24BPP(void *start, size_t cnt, unsigned int val);

/**
 * @brief Optimized function to draw a row of 32BPP pixels.
 *
 * @param start A pointer to starting byte in the buffer
 * @param cnt A number of pixels to write
 * @param val A pixel value to be written.
 */
void gp_write_pixels_32BPP(void *start, size_t cnt, unsigned int val);

#endif /* GP_WRITE_PIXELS_GEN_H */
